# OrgUpstreamUserIdentity

Upstream user identity data assigned to an org. THe UpstreamUserIdentity record is not specific to an org. This record would associate a user org record (User configured in a particular organisation), to an upstream identity. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**spec** | [**OrgUpstreamUserIdentitySpec**](OrgUpstreamUserIdentitySpec.md) |  | 
**metadata** | [**MetadataWithId**](MetadataWithId.md) |  | [optional] 
**status** | [**OrgUpstreamUserIdentityStatus**](OrgUpstreamUserIdentityStatus.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


